Class: Aws::SMS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SMS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sms/client.rb,
sig/client.rbs
Overview
An API client for SMS. To construct a client, you need to configure a :region and :credentials.
client = Aws::SMS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAppResponseSuccess, _CreateReplicationJobResponseSuccess, _DeleteAppLaunchConfigurationResponseSuccess, _DeleteAppReplicationConfigurationResponseSuccess, _DeleteAppResponseSuccess, _DeleteAppValidationConfigurationResponseSuccess, _DeleteReplicationJobResponseSuccess, _DeleteServerCatalogResponseSuccess, _DisassociateConnectorResponseSuccess, _GenerateChangeSetResponseSuccess, _GenerateTemplateResponseSuccess, _GetAppLaunchConfigurationResponseSuccess, _GetAppReplicationConfigurationResponseSuccess, _GetAppResponseSuccess, _GetAppValidationConfigurationResponseSuccess, _GetAppValidationOutputResponseSuccess, _GetConnectorsResponseSuccess, _GetReplicationJobsResponseSuccess, _GetReplicationRunsResponseSuccess, _GetServersResponseSuccess, _ImportAppCatalogResponseSuccess, _ImportServerCatalogResponseSuccess, _LaunchAppResponseSuccess, _ListAppsResponseSuccess, _NotifyAppValidationOutputResponseSuccess, _PutAppLaunchConfigurationResponseSuccess, _PutAppReplicationConfigurationResponseSuccess, _PutAppValidationConfigurationResponseSuccess, _StartAppReplicationResponseSuccess, _StartOnDemandAppReplicationResponseSuccess, _StartOnDemandReplicationRunResponseSuccess, _StopAppReplicationResponseSuccess, _TerminateAppResponseSuccess, _UpdateAppResponseSuccess, _UpdateReplicationJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app(params = {}) ⇒ Types::CreateAppResponse
Creates an application.
-
#create_replication_job(params = {}) ⇒ Types::CreateReplicationJobResponse
Creates a replication job.
-
#delete_app(params = {}) ⇒ Struct
Deletes the specified application.
-
#delete_app_launch_configuration(params = {}) ⇒ Struct
Deletes the launch configuration for the specified application.
-
#delete_app_replication_configuration(params = {}) ⇒ Struct
Deletes the replication configuration for the specified application.
-
#delete_app_validation_configuration(params = {}) ⇒ Struct
Deletes the validation configuration for the specified application.
-
#delete_replication_job(params = {}) ⇒ Struct
Deletes the specified replication job.
-
#delete_server_catalog(params = {}) ⇒ Struct
Deletes all servers from your server catalog.
-
#disassociate_connector(params = {}) ⇒ Struct
Disassociates the specified connector from Server Migration Service.
-
#generate_change_set(params = {}) ⇒ Types::GenerateChangeSetResponse
Generates a target change set for a currently launched stack and writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.
-
#generate_template(params = {}) ⇒ Types::GenerateTemplateResponse
Generates an CloudFormation template based on the current launch configuration and writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.
-
#get_app(params = {}) ⇒ Types::GetAppResponse
Retrieve information about the specified application.
-
#get_app_launch_configuration(params = {}) ⇒ Types::GetAppLaunchConfigurationResponse
Retrieves the application launch configuration associated with the specified application.
-
#get_app_replication_configuration(params = {}) ⇒ Types::GetAppReplicationConfigurationResponse
Retrieves the application replication configuration associated with the specified application.
-
#get_app_validation_configuration(params = {}) ⇒ Types::GetAppValidationConfigurationResponse
Retrieves information about a configuration for validating an application.
-
#get_app_validation_output(params = {}) ⇒ Types::GetAppValidationOutputResponse
Retrieves output from validating an application.
-
#get_connectors(params = {}) ⇒ Types::GetConnectorsResponse
Describes the connectors registered with the Server Migration Service.
-
#get_replication_jobs(params = {}) ⇒ Types::GetReplicationJobsResponse
Describes the specified replication job or all of your replication jobs.
-
#get_replication_runs(params = {}) ⇒ Types::GetReplicationRunsResponse
Describes the replication runs for the specified replication job.
-
#get_servers(params = {}) ⇒ Types::GetServersResponse
Describes the servers in your server catalog.
-
#import_app_catalog(params = {}) ⇒ Struct
Allows application import from Migration Hub.
-
#import_server_catalog(params = {}) ⇒ Struct
Gathers a complete list of on-premises servers.
-
#launch_app(params = {}) ⇒ Struct
Launches the specified application as a stack in CloudFormation.
-
#list_apps(params = {}) ⇒ Types::ListAppsResponse
Retrieves summaries for all applications.
-
#notify_app_validation_output(params = {}) ⇒ Struct
Provides information to Server Migration Service about whether application validation is successful.
-
#put_app_launch_configuration(params = {}) ⇒ Struct
Creates or updates the launch configuration for the specified application.
-
#put_app_replication_configuration(params = {}) ⇒ Struct
Creates or updates the replication configuration for the specified application.
-
#put_app_validation_configuration(params = {}) ⇒ Struct
Creates or updates a validation configuration for the specified application.
-
#start_app_replication(params = {}) ⇒ Struct
Starts replicating the specified application by creating replication jobs for each server in the application.
-
#start_on_demand_app_replication(params = {}) ⇒ Struct
Starts an on-demand replication run for the specified application.
-
#start_on_demand_replication_run(params = {}) ⇒ Types::StartOnDemandReplicationRunResponse
Starts an on-demand replication run for the specified replication job.
-
#stop_app_replication(params = {}) ⇒ Struct
Stops replicating the specified application by deleting the replication job for each server in the application.
-
#terminate_app(params = {}) ⇒ Struct
Terminates the stack for the specified application.
-
#update_app(params = {}) ⇒ Types::UpdateAppResponse
Updates the specified application.
-
#update_replication_job(params = {}) ⇒ Struct
Updates the specified settings for the specified replication job.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-sms/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2215 2216 2217 |
# File 'lib/aws-sdk-sms/client.rb', line 2215 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2218 2219 2220 |
# File 'lib/aws-sdk-sms/client.rb', line 2218 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'lib/aws-sdk-sms/client.rb', line 2188 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SMS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sms' context[:gem_version] = '1.77.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app(params = {}) ⇒ Types::CreateAppResponse
Creates an application. An application consists of one or more server groups. Each server group contain one or more servers.
89 |
# File 'sig/client.rbs', line 89
def create_app: (
|
#create_replication_job(params = {}) ⇒ Types::CreateReplicationJobResponse
Creates a replication job. The replication job schedules periodic replication runs to replicate your server to Amazon Web Services. Each replication run creates an Amazon Machine Image (AMI).
132 |
# File 'sig/client.rbs', line 132
def create_replication_job: (
|
#delete_app(params = {}) ⇒ Struct
Deletes the specified application. Optionally deletes the launched stack associated with the application and all Server Migration Service replication jobs for servers in the application.
150 |
# File 'sig/client.rbs', line 150
def delete_app: (
|
#delete_app_launch_configuration(params = {}) ⇒ Struct
Deletes the launch configuration for the specified application.
161 |
# File 'sig/client.rbs', line 161
def delete_app_launch_configuration: (
|
#delete_app_replication_configuration(params = {}) ⇒ Struct
Deletes the replication configuration for the specified application.
170 |
# File 'sig/client.rbs', line 170
def delete_app_replication_configuration: (
|
#delete_app_validation_configuration(params = {}) ⇒ Struct
Deletes the validation configuration for the specified application.
179 |
# File 'sig/client.rbs', line 179
def delete_app_validation_configuration: (
|
#delete_replication_job(params = {}) ⇒ Struct
Deletes the specified replication job.
After you delete a replication job, there are no further replication runs. Amazon Web Services deletes the contents of the Amazon S3 bucket used to store Server Migration Service artifacts. The AMIs created by the replication runs are not deleted.
188 |
# File 'sig/client.rbs', line 188
def delete_replication_job: (
|
#delete_server_catalog(params = {}) ⇒ Struct
Deletes all servers from your server catalog.
197 |
# File 'sig/client.rbs', line 197
def delete_server_catalog: (
|
#disassociate_connector(params = {}) ⇒ Struct
Disassociates the specified connector from Server Migration Service.
After you disassociate a connector, it is no longer available to support replication jobs.
205 |
# File 'sig/client.rbs', line 205
def disassociate_connector: (
|
#generate_change_set(params = {}) ⇒ Types::GenerateChangeSetResponse
Generates a target change set for a currently launched stack and writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.
215 |
# File 'sig/client.rbs', line 215
def generate_change_set: (
|
#generate_template(params = {}) ⇒ Types::GenerateTemplateResponse
Generates an CloudFormation template based on the current launch configuration and writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.
226 |
# File 'sig/client.rbs', line 226
def generate_template: (
|
#get_app(params = {}) ⇒ Types::GetAppResponse
Retrieve information about the specified application.
239 |
# File 'sig/client.rbs', line 239
def get_app: (
|
#get_app_launch_configuration(params = {}) ⇒ Types::GetAppLaunchConfigurationResponse
Retrieves the application launch configuration associated with the specified application.
252 |
# File 'sig/client.rbs', line 252
def get_app_launch_configuration: (
|
#get_app_replication_configuration(params = {}) ⇒ Types::GetAppReplicationConfigurationResponse
Retrieves the application replication configuration associated with the specified application.
262 |
# File 'sig/client.rbs', line 262
def get_app_replication_configuration: (
|
#get_app_validation_configuration(params = {}) ⇒ Types::GetAppValidationConfigurationResponse
Retrieves information about a configuration for validating an application.
273 |
# File 'sig/client.rbs', line 273
def get_app_validation_configuration: (
|
#get_app_validation_output(params = {}) ⇒ Types::GetAppValidationOutputResponse
Retrieves output from validating an application.
283 |
# File 'sig/client.rbs', line 283
def get_app_validation_output: (
|
#get_connectors(params = {}) ⇒ Types::GetConnectorsResponse
Describes the connectors registered with the Server Migration Service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
294 |
# File 'sig/client.rbs', line 294
def get_connectors: (
|
#get_replication_jobs(params = {}) ⇒ Types::GetReplicationJobsResponse
Describes the specified replication job or all of your replication jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
306 |
# File 'sig/client.rbs', line 306
def get_replication_jobs: (
|
#get_replication_runs(params = {}) ⇒ Types::GetReplicationRunsResponse
Describes the replication runs for the specified replication job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def get_replication_runs: (
|
#get_servers(params = {}) ⇒ Types::GetServersResponse
Describes the servers in your server catalog.
Before you can describe your servers, you must import them using ImportServerCatalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
335 |
# File 'sig/client.rbs', line 335
def get_servers: (
|
#import_app_catalog(params = {}) ⇒ Struct
Allows application import from Migration Hub.
351 |
# File 'sig/client.rbs', line 351
def import_app_catalog: (
|
#import_server_catalog(params = {}) ⇒ Struct
Gathers a complete list of on-premises servers. Connectors must be installed and monitoring all servers to import.
This call returns immediately, but might take additional time to retrieve all the servers.
360 |
# File 'sig/client.rbs', line 360
def import_server_catalog: (
|
#launch_app(params = {}) ⇒ Struct
Launches the specified application as a stack in CloudFormation.
368 |
# File 'sig/client.rbs', line 368
def launch_app: (
|
#list_apps(params = {}) ⇒ Types::ListAppsResponse
Retrieves summaries for all applications.
379 |
# File 'sig/client.rbs', line 379
def list_apps: (
|
#notify_app_validation_output(params = {}) ⇒ Struct
Provides information to Server Migration Service about whether application validation is successful.
390 |
# File 'sig/client.rbs', line 390
def notify_app_validation_output: (
|
#put_app_launch_configuration(params = {}) ⇒ Struct
Creates or updates the launch configuration for the specified application.
404 |
# File 'sig/client.rbs', line 404
def put_app_launch_configuration: (
|
#put_app_replication_configuration(params = {}) ⇒ Struct
Creates or updates the replication configuration for the specified application.
460 |
# File 'sig/client.rbs', line 460
def put_app_replication_configuration: (
|
#put_app_validation_configuration(params = {}) ⇒ Struct
Creates or updates a validation configuration for the specified application.
503 |
# File 'sig/client.rbs', line 503
def put_app_validation_configuration: (
|
#start_app_replication(params = {}) ⇒ Struct
Starts replicating the specified application by creating replication jobs for each server in the application.
569 |
# File 'sig/client.rbs', line 569
def start_app_replication: (
|
#start_on_demand_app_replication(params = {}) ⇒ Struct
Starts an on-demand replication run for the specified application.
578 |
# File 'sig/client.rbs', line 578
def start_on_demand_app_replication: (
|
#start_on_demand_replication_run(params = {}) ⇒ Types::StartOnDemandReplicationRunResponse
Starts an on-demand replication run for the specified replication job. This replication run starts immediately. This replication run is in addition to the ones already scheduled.
There is a limit on the number of on-demand replications runs that you can request in a 24-hour period.
589 |
# File 'sig/client.rbs', line 589
def start_on_demand_replication_run: (
|
#stop_app_replication(params = {}) ⇒ Struct
Stops replicating the specified application by deleting the replication job for each server in the application.
599 |
# File 'sig/client.rbs', line 599
def stop_app_replication: (
|
#terminate_app(params = {}) ⇒ Struct
Terminates the stack for the specified application.
608 |
# File 'sig/client.rbs', line 608
def terminate_app: (
|
#update_app(params = {}) ⇒ Types::UpdateAppResponse
Updates the specified application.
620 |
# File 'sig/client.rbs', line 620
def update_app: (
|
#update_replication_job(params = {}) ⇒ Struct
Updates the specified settings for the specified replication job.
662 |
# File 'sig/client.rbs', line 662
def update_replication_job: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2208 2209 2210 |
# File 'lib/aws-sdk-sms/client.rb', line 2208 def waiter_names [] end |