Class: Aws::SMS::Types::GetServersResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_modified_onTime

The time when the server was last modified.



879
880
881
882
883
884
885
886
# File 'lib/aws-sdk-sms/types.rb', line 879

class GetServersResponse < Struct.new(
  :last_modified_on,
  :server_catalog_status,
  :server_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token required to retrieve the next set of results. This value is null when there are no more results to return.



879
880
881
882
883
884
885
886
# File 'lib/aws-sdk-sms/types.rb', line 879

class GetServersResponse < Struct.new(
  :last_modified_on,
  :server_catalog_status,
  :server_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#server_catalog_statusString

The status of the server catalog.



879
880
881
882
883
884
885
886
# File 'lib/aws-sdk-sms/types.rb', line 879

class GetServersResponse < Struct.new(
  :last_modified_on,
  :server_catalog_status,
  :server_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#server_listArray<Types::Server>

Information about the servers.



879
880
881
882
883
884
885
886
# File 'lib/aws-sdk-sms/types.rb', line 879

class GetServersResponse < Struct.new(
  :last_modified_on,
  :server_catalog_status,
  :server_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end