Class: Aws::SMS::Types::ReplicationJob

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sms/types.rb

Overview

Represents a replication job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the replication job.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

Indicates whether the replication job should produce encrypted AMIs.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#frequencyInteger

The time between consecutive replication runs, in hours.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is enabled but a KMS key ID is not specified, the customer’s default KMS key for Amazon EBS is used.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#latest_ami_idString

The ID of the latest Amazon Machine Image (AMI).



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#license_typeString

The license type to be used for the AMI created by a successful replication run.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_replication_run_start_timeTime

The start time of the next replication run.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_recent_amis_to_keepInteger

The number of recent AMIs to keep in the customer’s account for a replication job. By default, the value is set to zero, meaning that all AMIs are kept.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#replication_job_idString

The ID of the replication job.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#replication_run_listArray<Types::ReplicationRun>

Information about the replication runs.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the IAM role to be used by Server Migration Service.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#run_onceBoolean

Indicates whether to run the replication job one time.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#seed_replication_timeTime

The seed replication time.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#server_idString

The ID of the server.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#server_typeString

The type of server.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the replication job.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The description of the current status of the replication job.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end

#vm_serverTypes::VmServer

Information about the VM server.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-sms/types.rb', line 1286

class ReplicationJob < Struct.new(
  :replication_job_id,
  :server_id,
  :server_type,
  :vm_server,
  :seed_replication_time,
  :frequency,
  :run_once,
  :next_replication_run_start_time,
  :license_type,
  :role_name,
  :latest_ami_id,
  :state,
  :status_message,
  :description,
  :number_of_recent_amis_to_keep,
  :encrypted,
  :kms_key_id,
  :replication_run_list)
  SENSITIVE = []
  include Aws::Structure
end